@@ -1,11 +1,11 @@
 ;;; internal-drag-and-drop.el --- Internal drag and drop interface
 
-;; Copyright (C) 1996, 1997 Heiko Muenkel
+;; Copyright (C) 1996 - 1998 Heiko Muenkel
 
 ;; Author: Heiko Muenkel <muenkel@tnt.uni-hannover.de>
 ;; Keywords: mouse
 
-;; $Id: internal-drag-and-drop.el,v 1.9 1997/07/20 06:36:20 muenkel Exp $
+;; $Id: internal-drag-and-drop.el,v 6.22 2000/10/06 08:46:00 youngs Exp $
 
 ;; This file is part of XEmacs.
 
@@ -129,7 +129,7 @@ this."
 		 (const :tag "Press button during mouse move"
 			:value press-button-during-move)))
 
-(defvar idd-global-mouse-keys (if (adapt-emacs19p)
+(defvar idd-global-mouse-keys (if (adapt-emacsp)
 				  (if (eq idd-drag-and-drop-mouse-binding-type
 					  'click)
 				      [(meta control mouse-1)]
@@ -153,7 +153,7 @@ before loading the package internal-drag-and-drop, the mouse will
 be bind in the right way.")
 
 (defvar idd-global-help-mouse-keys
-  (if (adapt-emacs19p)
+  (if (adapt-emacsp)
       (if (eq idd-drag-and-drop-mouse-binding-type 'click)
 	  [(meta control mouse-3)]
 	[(meta control down-mouse-3)])
@@ -217,13 +217,13 @@ with <specification-type> :== idd-if-minor-mode-p | idd-if-buffer-name-p
 
 The <specification-type> - functions must have two arguments, the first one
 is the source or destination and the second is the <value>. It must return
-nil, if the test wasn't successfull and a number (in general 1), which 
+nil, if the test wasn't successful and a number (in general 1), which 
 specifies the weight of the test function. The weights of all single tests
 are added to a summary weight and assigned to the action. The action
 with the highest weight is called from the action handler. Look at
 the definition of `idd-if-major-mode-p', `idd-if-minor-mode-p' and so on for
 examples. Look at the function `idd-get-source-or-destination-alist', if
-you wan't to know the structure of the 'source-or-destination' argument
+you want to know the structure of the 'source-or-destination' argument
 of these functions.
 
 The <destination-specification> looks like <source-specification>,
@@ -238,7 +238,7 @@ buffer must only have a specific mode. But however, it's also possible
 to define a general `idd-actions' list, where the destination mode is
 specified by `idd-if-major-mode-p'.
 
-<action> ist a function, which has two arguments, the first specifies the
+<action> is a function, which has two arguments, the first specifies the
 source and the second the destination. Look at the function definition
 of `idd-action-copy-region' and `idd-action-copy-replace-region'. They are 
 examples for such actions."
@@ -264,8 +264,11 @@ this variable."
   :group 'idd-drag-and-drop
   :type 'file)
 
-(defcustom idd-data-directory (file-name-as-directory 
-			       (expand-file-name "idd" data-directory))
+(defcustom idd-data-directory (or 
+			       (and (fboundp 'locate-data-directory)
+				    (locate-data-directory "hm--html-menus"))
+			       (file-name-as-directory 
+				(expand-file-name "idd" data-directory)))
   "Data directory for the file `idd-mouse-pointer-image'.
 Run the command `idd-make-drag-and-drop-pointer-glyph' after changing
 this variable."
@@ -533,7 +536,7 @@ The position and the buffer is specified by SOURCE-OR-DESTINATION."
 (defun idd-if-dired-file-on-line-p (source-or-destination filename-regexp)
   "Checks, if the filename on the line match FILENAME-REGEXP.
 The function `dired-get-filename' is used, to get the filename from
-the SOURCE-OR-DESTINATION. It returns 1, if it matchs or nil."
+the SOURCE-OR-DESTINATION. It returns 1, if it matches or nil."
   (let ((case-fold-search t))
     (if (and (idd-get-dired-filename-from-line source-or-destination)
 	     (string-match filename-regexp
@@ -595,8 +598,8 @@ It returns 1 if this is the case or nil otherwise."
 (defun idd-if-modifiers-p (source-or-destination modifiers)
   "Checks, if the MODIFIERS hold during selecting the SOURCE-OR-DESTINATION.
 Returns 1, if the list MODIFIERS contains the same modifiers,
-or if any modyfiers are hold and MODIFIERS is t,
-or if no modyfiers are hold and MODIFIERS is nil.
+or if any modifiers are hold and MODIFIERS is t,
+or if no modifiers are hold and MODIFIERS is nil.
 Otherwise nil is returned."
   (let ((event-modifiers (event-modifiers
 			  (cdr (assoc ':event source-or-destination)))))
@@ -630,7 +633,7 @@ Otherwise nil is returned."
 					    &key
 					    do-in-source
 					    do-in-destination)
-  "Macro, usefull for the definition of action functions.
+  "Macro, useful for the definition of action functions.
 Look at the example `idd-action-move-region'."
   `(progn
      (if (idd-if-region-active-p ,source t)
@@ -731,7 +734,7 @@ button event. Therefore this should not be bind direct to a mouse button."
 	  (next-command-event nil drag-and-drop-message))
     (if (button-press-event-p source-event)
 	(progn
-	  (when (and (adapt-emacs19p)
+	  (when (and (adapt-emacsp)
 		     (mouse-event-p source-event)
 		     (eq idd-drag-and-drop-mouse-binding-type 'click))
 	    (while (not (button-release-event-p (next-command-event)))))
@@ -805,7 +808,7 @@ destination region."
 	  (next-command-event nil drag-and-drop-message))
     (message "")
     (cond ((or (button-release-event-p destination-event)
-	       (and (adapt-emacs19p)
+	       (and (adapt-emacsp)
 		    (button-drag-event-p destination-event)))
 	   (setq destination (idd-get-source-or-destination-alist
 			      destination-event))
@@ -844,7 +847,7 @@ button-press-event."
 	   (setq destination (idd-get-source-or-destination-alist
 			      destination-event))
 	   (idd-set-point destination)
-;	   (when (adapt-emacs19p)
+;	   (when (adapt-emacsp)
 ;	       (while (not (button-release-event-p (next-command-event)))))
 	   (if idd-help-instead-of-action
 	       (idd-display-help-about-action (idd-get-action source
@@ -855,7 +858,7 @@ button-press-event."
 	     (idd-call-action (idd-get-action source destination idd-actions)
 			      source
 			      destination)))
-	  ((and (adapt-emacs19p)
+	  ((and (adapt-emacsp)
 		(button-click-event-p destination-event))
 	   (setq destination (idd-get-source-or-destination-alist
 			      destination-event))
@@ -913,7 +916,8 @@ You've to rerun this, if you change either the variable
 	    (message 
 	     "Warning: Can't find drag and drop mouse pointer image!"))))
       
-      (idd-make-drag-and-drop-pointer-glyph)
+      (when (and (not noninteractive) (console-on-window-system-p))
+	(idd-make-drag-and-drop-pointer-glyph))
       
       ))
 
@@ -922,7 +926,7 @@ You've to rerun this, if you change either the variable
     (progn
       (setq idd-help-start-action-keymap
 	    (make-sparse-keymap 'idd-help-start-action-keymap))
-      (if (adapt-emacs19p)
+      (if (adapt-emacsp)
 	  (define-key idd-help-start-action-keymap [(mouse-2)]
 	    'idd-help-start-action)
 	(define-key idd-help-start-action-keymap "[(button2)]"
